pub struct LinkInfo {Show 13 fields
pub size: u32,
pub header_size: u32,
pub flags: LinkInfoFlags,
pub volume_id_offset: u32,
pub local_base_path_offset: u32,
pub common_network_relative_link_offset: u32,
pub common_path_suffix_offset: u32,
pub local_base_path_offset_unicode: Option<u32>,
pub common_path_suffix_offset_unicode: Option<u32>,
pub volume_id: Option<VolumeID>,
pub local_base_path: Option<String>,
pub common_network_relative_link: Option<CommonNetworkRelativeLink>,
pub common_path_suffix: Option<String>,
}Expand description
The LinkInfo structure specifies information necessary to resolve a link target if it is not found in its original location.
Fields
size: u32header_size: u32flags: LinkInfoFlagsvolume_id_offset: u32local_base_path_offset: u32common_network_relative_link_offset: u32common_path_suffix_offset: u32local_base_path_offset_unicode: Option<u32>common_path_suffix_offset_unicode: Option<u32>volume_id: Option<VolumeID>local_base_path: Option<String>common_network_relative_link: Option<CommonNetworkRelativeLink>common_path_suffix: Option<String>Implementations
Sourceimpl LinkInfo
impl LinkInfo
pub fn get_size(&self) -> &u32
pub fn get_header_size(&self) -> &u32
pub fn get_flags(&self) -> &LinkInfoFlags
pub fn get_volume_id_offset(&self) -> &u32
pub fn get_local_base_path_offset(&self) -> &u32
pub fn get_common_network_relative_link_offset(&self) -> &u32
pub fn get_common_path_suffix_offset(&self) -> &u32
pub fn get_local_base_path_offset_unicode(&self) -> &Option<u32>
pub fn get_common_path_suffix_offset_unicode(&self) -> &Option<u32>
pub fn get_volume_id(&self) -> &Option<VolumeID>
pub fn get_local_base_path(&self) -> &Option<String>
pub fn get_common_network_relative_link( &self, ) -> &Option<CommonNetworkRelativeLink>
pub fn get_common_path_suffix(&self) -> &Option<String>
Sourceimpl LinkInfo
impl LinkInfo
pub fn from_buffer(buf: &[u8]) -> Result<Self, ReaderError>
pub fn from_reader<R: Read + Seek>(r: &mut R) -> Result<Self, ReaderError>